# PSYCH 4165 Lab 1
# command file for computing a repeated measures
# analysis of variance using lme() in R.
# Lewis O. Harvey, Jr.
# Department of Psychology
# University of Colorado
# 26 January 2014

# load the nlme library to use lme()
library(nlme)

# read in group data in wide format (from Excel text file)
fn <- file("lab_1_group_data_wide_Spring_2014.csv")
df.wide <- read.csv(fn, header=TRUE)

# *******************************p***********************
# reshape the file into long format
# Note: reshape() is a bit of a pain to use but what it does
# is take data that are in a so-called wide format
# (one row per subject, separate columns per dependent variable)
# and put it into the long formate needed by many R analysis routines
# (multiple rows per subject, single column per dependent variable)
df.long <- reshape(df.wide,
	varying = list(c("mu00","mu45"), c("sd00", "sd45"), c("aic00", "aic45")),
	idvar = "subject",
	times = c("00", "45"),
	v.names = c("mu", "sd", "aic"),
	timevar = "standard",
	direction = "long")
rownames(df.long) <- 1:dim(df.long)[1]
df.long$standard <- factor(df.long$standard) # make standard a factor
# ******************************************************

df <- df.long # use shorter name for the data frame

# Write out a summary of the variables in the data frame:
print(summary(df))

# ******************************************************
# plotting section
# define eight functions to plot the two sets of graphs
# plot1() JND data
# plot2() JND data
# plot3() AIC data
# plot4() AIC data
# plot5() scatter plots of mu, sd, aic
# plot6() scatter plots for 0.0 deg standard
# plot7() scatter plots for 45.0 deg standard
# plot8() mu vs sd plot
# To make the plots, type the command

# ******************************************************
# Make a strip chart of JND for each standard orientation
plot1 <- function() {
	# set graphic parameters to plot two graphs in one panel
	par(mfcol = c(1,2))
	stripchart(sd ~ standard, data = df,
		method = "jitter", jitter = 0.07,
		vertical = TRUE,
		xlim = c(0.75, 2.25),
		xlab = "Standard Orientation", 
		ylab = "Orientation JND in Degrees", 
		main = "PSYC 4165 - Spring 2014")
	abline(h = 0, col = "red")

	# Make a box plot of JND for each standard orientation
	boxplot(sd ~ standard, data = df,
		col = "yellow",
		horizontal = FALSE,
		xlab = "Standard Orientation",
		ylab = "Orientation JND in Degrees", 
		main = "PSYC 4165 - Spring 2014")
	abline(h = 0, col = "red")
	par(mfcol = c(1,1))
}

# ******************************************************
# Make a strip chart of JND for each testing order
plot2 <- function() {
	# set graphic parameters to plot two graphs in one panel
	par(mfcol = c(1,2))
	stripchart(sd ~ order, data = df,
		method = "jitter", jitter = 0.07,
		vertical = TRUE,
		xlim = c(0.75, 2.25),
		xlab = "Testing Order",
		ylab = "Orientation JND in Degrees", 
		main = "PSYC 4165 - Spring 2014")
	abline(h = 0, col = "red")

	# Make a box plot of mean for each testing order
	boxplot(sd ~ order, data = df,
		col = "yellow",
		horizontal = FALSE,
		xlab = "Testing Order",
		ylab = "Orientation JND in Degrees", 
		main = "PSYC 4165 - Spring 2014")
	abline(h = 0, col = "red")
	par(mfcol = c(1,1))
}
# ******************************************************

# Make a strip chart of AIC for each standard orientation
plot3 <- function() {
	# set graphic parameters to plot two graphs in one panel
	par(mfcol = c(1,2))
	stripchart(aic ~ standard, data = df,
		method = "jitter", jitter = 0.07,
		vertical = TRUE,
		xlim = c(0.75, 2.25),
		xlab = "Standard Orientation", 
		ylab = "Goodness-of-Fit (AIC)", 
		main = "PSYC 4165 - Spring 2014")

	# Make a box plot of PSE for each standard orientation
	boxplot(aic ~ standard, data = df,
		col = "yellow",
		horizontal = FALSE,
		xlab = "Standard Orientation",
		ylab = "Goodness-of-Fit (AIC)", 
		main = "PSYC 4165 - Spring 2014")
	par(mfcol = c(1,1))
}
# ******************************************************

# Make a strip chart of AIC for each order
plot4 <- function() {
    # set graphic parameters to plot two graphs in one panel
    par(mfcol = c(1,2))
    stripchart(aic ~ order, data = df,
               method = "jitter", jitter = 0.07,
               vertical = TRUE,
               xlim = c(0.75, 2.25),
               xlab = "Testing Order",
               ylab = "Goodness-of-Fit (AIC)", 
               main = "PSYC 4165 - Spring 2014")
    
    # Make a box plot of aic for each order
    boxplot(aic ~ order, data = df,
            col = "yellow",
            horizontal = FALSE,
            xlab = "Testing Order",
            ylab = "Goodness-of-Fit (AIC)", 
            main = "PSYC 4165 - Spring 2014")
    par(mfcol = c(1,1))
}
# ******************************************************

# make scatter plots of all three continuous dependent variables
plot5 <- function() {
	par(mfcol = c(1,1))
	pairs(df[, c("mu", "sd", "aic")])
	par(mfcol = c(1,1))
}
# ******************************************************

# make scatter plots of all three continuous dependent variables
# for the 0 deg standard
plot6 <- function() {
	par(mfcol = c(1, 2))
	pairs(subset(df, standard == "00")[, c("mu", "sd", "aic")], main = "0 deg Standard")
	par(mfcol = c(1, 1))
}
# ******************************************************

# make scatter plots of all three continuous dependent variables
# for the 45 deg standard
plot7 <- function() {
	par(mfcol = c(1, 2))
	pairs(subset(df, standard == "45")[, c("mu", "sd", "aic")], main = "45 deg Standard")
	par(mfcol = c(1, 1))
}
# ******************************************************

# plot the JND of 0.0 deg against the JND for 45 deg
# ******************************************************
plot8 <- function() {
	df.x <- subset(df, standard == "00")
	df.y <- subset(df, standard == "45")
	plot(df.y[,"sd"] ~ df.x[,"sd"],
		pch = 19,
		xlab = "JND for 0.0 degrees",
		ylab = "JND for 45.0 degrees",
		main = "JND vs Standard Orientation")
	lm.mod <- lm(df.y[,"sd"] ~ df.x[,"sd"])
	abline(lm.mod)
	print(summary(lm.mod))
}

# compute the mean JNDs
print(" ", quote = FALSE)
print("mean JND of orders", quote = FALSE)
print(with(df,tapply(sd, order, "mean")))
print(" ", quote = FALSE)
print("mean JND of standards", quote = FALSE)
print(with(df,tapply(sd, standard, "mean")))

# compute the mean AICs
print(" ", quote = FALSE)
print("mean AIC of orders", quote = FALSE)
print(with(df,tapply(aic, order, "mean")))
print(" ", quote = FALSE)
print("mean AIC of standards", quote = FALSE)
print(with(df,tapply(aic, standard, "mean")))

# compute the mixed effects linear model with lme()
# use lme() to compute the ANOVA on JNDs
print(" ", quote = FALSE)
print("Results of Linear Mixed Effects Analysis of Variance on JND (lme)", quote = FALSE)

lme.jnd <- mod <- lme(sd ~ standard * order, data = df, random = ~ 1 + standard | subject)
print(anova(lme.jnd))

# use lme() to compute the ANOVA on AICs
print(" ", quote = FALSE)
print("Results of Linear Mixed Effects Analysis of Variance on AIC (lme)", quote = FALSE)

lme.aic <- mod <- lme(aic ~ standard * order, data = df, random = ~ 1 + standard | subject)
print(anova(lme.aic))
plot1()
